#include <ArduinoBLE.h>

BLEService brailleService("19B10000-E8F2-537E-4F6C-D104768A1214");  // create service

// create switch characteristic and allow remote device to read and write
BLEByteCharacteristic vibrateCharacteristic("19B10001-E8F2-537E-4F6C-D104768A1214", BLERead | BLEWrite);

inline const char * typeStr (int   var) { return " int "; }
inline const char * typeStr (long  var) { return " long "; }
inline const char * typeStr (float var) { return " float "; }
inline const char * typeStr (const char *var) { return " char "; }

int interval = 200;

unsigned long previousMillis = 0;

bool toggle = false;

int motorArray[2][6] = {{3,2,5,6,11,8},{1,1,1,1,1,1}}; 
/* motors are arranged as such
3      6
2      11
5      8

*/

unsigned long currentMillis = millis();

void setup() {
  Serial.begin(9600);
  while (!Serial)
    ;

  pinMode(2, OUTPUT);
  pinMode(3, OUTPUT);
  pinMode(5, OUTPUT);
  pinMode(6, OUTPUT);
  pinMode(8, OUTPUT);
  pinMode(11, OUTPUT);

  // begin initialization
  if (!BLE.begin()) {
    Serial.println("starting Bluetooth® Low Energy module failed!");

    while (1)
      ;
  }

  // set the local name peripheral advertises
  BLE.setLocalName("HapticBrailleReader");
  // set the UUID for the service this peripheral advertises
  BLE.setAdvertisedService(brailleService);

  // add characteristics to the service
  brailleService.addCharacteristic(vibrateCharacteristic);

  // add service
  BLE.addService(brailleService);

  // assign event handlers for connected, disconnected to peripheral
  BLE.setEventHandler(BLEConnected, blePeripheralConnectHandler);
  BLE.setEventHandler(BLEDisconnected, blePeripheralDisconnectHandler);

  // assign event handlers for characteristic
  vibrateCharacteristic.setEventHandler(BLEWritten, vibrateCharacteristicWritten);
  // set an initial value for the characteristic
  vibrateCharacteristic.setValue(0);
  // start advertising
  BLE.advertise();

  Serial.println(("Bluetooth® device active, waiting for connections..."));
}

void loop() {
  // poll for Bluetooth® Low Energy events
  currentMillis = millis();
  BLE.poll();
  //Serial.print("toggle");
  //Serial.println(toggle);
  if (toggle == true){
    //Serial.println(currentMillis);
    if (currentMillis - previousMillis >= interval){
      turnOffMotors();
      Serial.println("---------------");
      toggle = false;
    }
  }
}

void blePeripheralConnectHandler(BLEDevice central) {
  // central connected event handler
  Serial.print("Connected event, central: ");
  Serial.println(central.address());
}

void blePeripheralDisconnectHandler(BLEDevice central) {
  // central disconnected event handler
  Serial.print("Disconnected event, central: ");
  Serial.println(central.address());
}

void vibrateCharacteristicWritten(BLEDevice central, BLECharacteristic characteristic) {
  // central wrote new value to characteristic, update LED
  Serial.print("vibrateCharacteristic event, written: ");
  //Serial.println(vibrateCharacteristic.value());
  Serial.print (typeStr(vibrateCharacteristic.value())); Serial.println (vibrateCharacteristic.value());
  //splitCode(vibrateCharacteristic.value()); // splits received value into 0s and 1s in the array
  splitCode(111222);

  previousMillis = currentMillis; // begins timer
  //Serial.print("previousMillis: ");
  //Serial.println(previousMillis);
  turnOnMotors(); 
  toggle = true;         // will turn the LED on 
}

void turnOffMotors(){
  for(int n = 0;n<6;n++){
    Serial.print(motorArray[0][n]);
    Serial.println(" is off");
    digitalWrite(motorArray[0][n], LOW); // turn off
    motorArray[1][n] = 1;
    
  }

}

void turnOnMotors(){ // turns on motors
  //array
  for(int n;n<6;n++){
    if(motorArray[1][n] == 2){
      digitalWrite(motorArray[0][n], HIGH);
      Serial.print(motorArray[0][n]);
      Serial.println(" is on");
    }
  }
  Serial.println();
}

void splitCode(int code){
  int counter = 5;
  Serial.println("splitcode start");
  Serial.print("code: ");
  Serial.println(code);
  while(code > 0){
    motorArray[1][counter] = code%10;
    code/=10;
    counter--;
  }

  Serial.println("splitcode end");
}


